#
# spec file for package ghc-these
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name these
%global pkgver %{pkg_name}-%{version}
Name:           ghc-%{pkg_name}
Version:        1.2.1
Release:        3.2
Summary:        An either-or-both data type
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/2.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-assoc-devel
BuildRequires:  ghc-assoc-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-binary-devel
BuildRequires:  ghc-binary-prof
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-hashable-prof
BuildRequires:  ghc-rpm-macros
ExcludeArch:    %{ix86}

%description
This package provides a data type 'These a b' which can hold a value of either
type or values of each type. This is usually thought of as an "inclusive or"
type (contrasting 'Either a b' as "exclusive or") or as an "outer join" type
(contrasting '(a, b)' as "inner join").

' data These a b = This a | That b | These a b '

Since version 1, this package was split into parts:

* <https://hackage.haskell.org/package/semialign semialign> For 'Align' and
'Zip' type-classes.

* <https://hackage.haskell.org/package/semialign-indexed semialign-indexed> For
'SemialignWithIndex' class, providing 'ialignWith' and 'izipWith'.

* <https://hackage.haskell.org/package/these-lens these-lens> For lens
combinators.

* <http://hackage.haskell.org/package/monad-chronicle monad-chronicle> For
transformers variant of 'These'.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sat Jan  4 2025 Peter Simons <psimons@suse.com>
- Update these to version 1.2.1 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Aug  2 2024 Peter Simons <psimons@suse.com>
- Update these to version 1.2.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu May 16 2024 Peter Simons <psimons@suse.com>
- Update these to version 1.2.1.
  [#] 1.2.1
  - Support GHC-8.6.5...GHC-9.10.1
* Thu Nov 16 2023 Peter Simons <psimons@suse.com>
- Drop obsolete dependency on foldable1-classes-compat.
* Wed Oct  4 2023 Peter Simons <psimons@suse.com>
- Update these to version 1.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat May 27 2023 Ondřej Súkup <mimi.vx@gmail.com>
- Update these to version 1.2.
  [#] 1.2
  - Depend on `bifunctor-classes-compat` instead of `bifunctors`
    See changelog note in `bifunctors-5.6`: https://hackage.haskell.org/package/bifunctors-5.6/changelog
    This is breaking change, but affects only GHC-8.0 and older users.
    In that case you should check various combinations of newer/older
    `bifunctors`, `these` (and e.g. `semialign`) packages.
  - Depend on `assoc-1.1`. Since version 1.1 `assoc` has an almost trivial
    dependency footprint, so `these` depends on it unconditionally.
  - Add `Bifoldable1 These` instance
  - Add `Foldable1 (Data.Functor.These1 f g)` instance
  - Change `Eq (These1 f g a)`, `Ord`, `Read`, `Show`, `NFData` instances similarly to how
    they are changed for `Product` and `Sum` in `base-4.18.0.0`.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Wed Aug 10 2022 Peter Simons <psimons@suse.com>
- Update these to version 1.1.1.1 revision 6.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Nov 16 2021 psimons@suse.com
- Update these to version 1.1.1.1 revision 5.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Nov  1 2021 psimons@suse.com
- Update these to version 1.1.1.1 revision 4.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Jul 28 2021 psimons@suse.com
- Update these to version 1.1.1.1 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Feb 15 2021 psimons@suse.com
- Update these to version 1.1.1.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Wed Jul 15 2020 psimons@suse.com
- Update these to version 1.1.1.1.
  [#] 1.1.1.1
  - Workaround GCC-4 C-preprocessor bug
* Fri Jul 10 2020 psimons@suse.com
- Update these to version 1.1.1.
  [#] 1.1.1
  - These doesn't depend on `base-compat` anymore
  - Add `NFData1/2`, `Hashable1/2`, `Eq1/2` ... instances
* Tue Jun  9 2020 psimons@suse.com
- Add these at version 1.1.
